@@ -8,12 +8,18 @@ pub struct Command {
     /// Path to the project, if not specified, current working directory will be used.
     #[structopt(short, long)]
     pub path: Option<String>,
+    /// Whether to compile using the IR pipeline.
+    #[structopt(long)]
+    pub use_ir: bool,
     /// Whether to compile to bytecode (false) or to print out the generated ASM (true).
     #[structopt(long)]
     pub print_finalized_asm: bool,
     /// Whether to compile to bytecode (false) or to print out the generated ASM (true).
     #[structopt(long)]
     pub print_intermediate_asm: bool,
+    /// Whether to compile to bytecode (false) or to print out the IR (true).
+    #[structopt(long)]
+    pub print_ir: bool,
     /// If set, outputs a binary file representing the script bytes.
     #[structopt(short = "o")]
     pub binary_outfile: Option<String>,
